@@ -5,7 +5,7 @@ Theses functions are meant to have no dependencies on the graphintrospect packag
 
 import json
 from enum import EnumMeta
-from typing import Any, Type, Union
+from typing import Any, Dict, Type
 
 
 # pylint: disable=no-value-for-parameter
@@ -37,7 +37,12 @@ class SetEncoder(json.JSONEncoder):
         return json.JSONEncoder.default(self, o)
 
 
-def dump_schema(path: str, schema: Union[Any, dict]) -> None:
+def json_encode_schema(schema: Any) -> Dict:
+    """Serialize the schema to a proper json encoding."""
+    return json.loads(json.dumps(schema, indent=2, cls=SetEncoder))
+
+
+def dump_schema(path: str, schema: Any) -> None:
     """Dump the schema to a file."""
     with open(path, 'w', encoding='utf-8') as f:
         f.write(json.dumps(schema, indent=2, cls=SetEncoder))
